#include "jmcopsync.h"
#include <sys/stat.h>

using namespace std;

class JMCOPSync_impl : public JMCOPSync_skel {
public:
	class Operation {
	public:
		virtual void execute() = 0;
	};

	class StartOperation : public Operation {
	public:
		Arts::SynthModule module;

		StartOperation(Arts::SynthModule module)
			: module(module) { }

		void execute() { module.start(); }
	};

	class StopOperation : public Operation {
	public:
		Arts::SynthModule module;

		StopOperation(Arts::SynthModule module)
			: module(module) { }

		void execute() { module.stop(); }
	};


	queue<Operation *> opQueue;

	void queueStart(Arts::SynthModule module)
	{
		opQueue.push(new StartOperation(module));
	}

	void queueStop(Arts::SynthModule module)
	{
		opQueue.push(new StopOperation(module));
	}

	void execute()
	{
		while(!opQueue.empty())
		{
			Operation *op = opQueue.front();
			opQueue.pop();

			op->execute();
			delete op;
		}
	}
};

REGISTER_IMPLEMENTATION(JMCOPSync_impl);
